summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/managedconnectionaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/managedconnectionaccount.h')
-rw-r--r--kopete/libkopete/managedconnectionaccount.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/libkopete/managedconnectionaccount.h b/kopete/libkopete/managedconnectionaccount.h
index 755fbf71..a27bd7cd 100644
--- a/kopete/libkopete/managedconnectionaccount.h
+++ b/kopete/libkopete/managedconnectionaccount.h
@@ -27,7 +27,7 @@ namespace Kopete
class Protocol;
/**
* A ManagedConnectionAccount queries the NetworkStatus KDED Module before trying to connect using
* connectwithPassword, starting a network connection if needed. If the network is not available,
* it delays calling performConnectWithPassword until it receives notification from the daemon
* that the network is up. The account receiveds notifications from the daemon of network failures
@@ -69,7 +69,7 @@ class KOPETE_EXPORT ManagedConnectionAccount : public PasswordedAccount
* @param host For future expansion.
* @param status the new status of the network
*/
- virtual void slotConnectionStatusChanged( const TQString & host, NetworkStatus::EnumStatus status );
+ virtual void slotConnectionStatusChanged( const TQString & host, NetworktqStatus::EnumtqStatus status );
private:
TQString m_password;
bool m_waitingForConnection;
@@ -27,7 +27,7 @@ namespace Kopete
class Protocol;
/**
- * A ManagedConnectionAccount queries the NetworkStatus KDED Module before trying to connect using
+ * A ManagedConnectionAccount queries the NetworktqStatus KDED Module before trying to connect using
* connectwithPassword, starting a network connection if needed. If the network is not available,
* it delays calling performConnectWithPassword until it receives notification from the daemon